@@ -25,7 +25,8 @@ if ( !isGeneric('mapView') ) {
 #' \code{sf} object or a list of any combination of those. Furthermore,
 #' this can also be a \code{data.frame} or a \code{numeric vector}. If missing,
 #' a blank map will be drawn.
-#' @param map an optional existing map to be updated/added to
+#' @param map an optional existing map to be updated/added to.
+#' @param band for stars layers, the band number to be plotted.
 #' @param pane name of the map pane in which to render features. See
 #' \code{\link{addMapPane}} for details. Currently only supported for vector layers.
 #' Ignored if \code{canvas = TRUE}. The default \code{"auto"} will create different panes
@@ -296,72 +297,75 @@ setMethod('mapView', signature(x = 'RasterLayer'),
 )
 
 
-# ## Stars layer ==================================================================
-# #' @describeIn mapView \code{\link{stars}}
-# setMethod('mapView', signature(x = 'stars'),
-#           function(x,
-#                    map = NULL,
-#                    maxpixels = mapviewGetOption("mapview.maxpixels"),
-#                    col.regions = mapviewGetOption("raster.palette")(256),
-#                    at = NULL,
-#                    na.color = mapviewGetOption("na.color"),
-#                    use.layer.names = FALSE,
-#                    values = NULL,
-#                    map.types = mapviewGetOption("basemaps"),
-#                    alpha.regions = 0.8,
-#                    legend = mapviewGetOption("legend"),
-#                    legend.opacity = 1,
-#                    trim = TRUE,
-#                    verbose = mapviewGetOption("verbose"),
-#                    layer.name = NULL,
-#                    homebutton = TRUE,
-#                    native.crs = FALSE,
-#                    method = c("bilinear", "ngb"),
-#                    label = TRUE,
-#                    query.type = c("mousemove", "click"),
-#                    query.digits,
-#                    query.position = "topright",
-#                    query.prefix = "Layer",
-#                    ...) {
-#
-#             method = match.arg(method)
-#             if(length(dim(x)) == 2) layer = x[[1]] else layer = x[[1]][, , 1]
-#             if (is.null(at)) at <- lattice::do.breaks(
-#               extendLimits(range(layer, na.rm = TRUE)),
-#               256
-#             )
-#
-#             if (mapviewGetOption("platform") == "leaflet") {
-#               leaflet_stars(x,
-#                             map = map,
-#                             maxpixels = maxpixels,
-#                             col.regions = col.regions,
-#                             at = at,
-#                             na.color, na.color,
-#                             use.layer.names = use.layer.names,
-#                             values = values,
-#                             map.types = map.types,
-#                             alpha.regions = alpha.regions,
-#                             legend = legend,
-#                             legend.opacity = legend.opacity,
-#                             trim = trim,
-#                             verbose = verbose,
-#                             layer.name = layer.name,
-#                             homebutton = homebutton,
-#                             native.crs = native.crs,
-#                             method = method,
-#                             label = label,
-#                             query.type = query.type,
-#                             query.digits = query.digits,
-#                             query.position = query.position,
-#                             query.prefix = query.prefix,
-#                             ...)
-#             } else {
-#               NULL
-#             }
-#
-#           }
-# )
+
+## Stars layer ==================================================================
+#' @describeIn mapView \code{\link{stars}}
+setMethod('mapView', signature(x = 'stars'),
+          function(x,
+                   band = 1,
+                   map = NULL,
+                   maxpixels = mapviewGetOption("mapview.maxpixels"),
+                   col.regions = mapviewGetOption("raster.palette")(256),
+                   at = NULL,
+                   na.color = mapviewGetOption("na.color"),
+                   use.layer.names = FALSE,
+                   values = NULL,
+                   map.types = mapviewGetOption("basemaps"),
+                   alpha.regions = 0.8,
+                   legend = mapviewGetOption("legend"),
+                   legend.opacity = 1,
+                   trim = TRUE,
+                   verbose = mapviewGetOption("verbose"),
+                   layer.name = NULL,
+                   homebutton = TRUE,
+                   native.crs = FALSE,
+                   method = c("bilinear", "ngb"),
+                   label = TRUE,
+                   query.type = c("mousemove", "click"),
+                   query.digits,
+                   query.position = "topright",
+                   query.prefix = "Layer",
+                   ...) {
+
+            method = match.arg(method)
+            if(length(dim(x)) == 2) layer = x[[1]] else layer = x[[1]][, , band]
+            if (is.null(at)) at <- lattice::do.breaks(
+              extendLimits(range(layer, na.rm = TRUE)),
+              256
+            )
+
+            if (mapviewGetOption("platform") == "leaflet") {
+              leaflet_stars(x,
+                            band = band,
+                            map = map,
+                            maxpixels = maxpixels,
+                            col.regions = col.regions,
+                            at = at,
+                            na.color = na.color,
+                            use.layer.names = use.layer.names,
+                            values = values,
+                            map.types = map.types,
+                            alpha.regions = alpha.regions,
+                            legend = legend,
+                            legend.opacity = legend.opacity,
+                            trim = trim,
+                            verbose = verbose,
+                            layer.name = layer.name,
+                            homebutton = homebutton,
+                            native.crs = native.crs,
+                            method = method,
+                            label = label,
+                            query.type = query.type,
+                            query.digits = query.digits,
+                            query.position = query.position,
+                            query.prefix = query.prefix,
+                            ...)
+            } else {
+              NULL
+            }
+
+          }
+)
 
 
 
@@ -479,7 +483,7 @@ setMethod('mapView', signature(x = 'sf'),
           function(x,
                    map = NULL,
                    pane = "auto",
-                   canvas = FALSE,
+                   canvas = useCanvas(x),
                    zcol = NULL,
                    burst = FALSE,
                    color = mapviewGetOption("vector.palette"),
@@ -504,6 +508,19 @@ setMethod('mapView', signature(x = 'sf'),
                    maxpoints = getMaxFeatures(x),
                    ...) {
 
+            if (nrow(x) == 0) {
+              stop("\n", deparse(substitute(x, env = parent.frame())),
+                   " does not contain data \n", call. = FALSE)
+            }
+
+            if (is.null(zcol)) legend = FALSE
+            if (!is.null(zcol) && !all(zcol %in% colnames(x))) {
+              stop("\n", "at least one of the following columns: \n",
+                   paste(zcol, collapse = ", "), "\nnot found in ",
+                   deparse(substitute(x, env = parent.frame())),
+                   call. = FALSE)
+            }
+
             if (mapviewGetOption("platform") == "leaflet") {
               if (is.character(burst)) {
                 zcol = burst
@@ -532,6 +549,8 @@ setMethod('mapView', signature(x = 'sf'),
                              na.alpha = na.alpha,
                              legend = legend)
 
+                lwd = lwd
+
                 if (is.function(tmp)) {
                   tmp = tmp()
                   x <- tmp$obj
@@ -592,6 +611,8 @@ setMethod('mapView', signature(x = 'sf'),
                         na.alpha = na.alpha,
                         canvas = canvas,
                         pane = pane,
+                        cex = cex,
+                        lwd = lwd,
                         ...)
 
               }
@@ -610,7 +631,7 @@ setMethod('mapView', signature(x = 'sfc'),
           function(x,
                    map = NULL,
                    pane = "auto",
-                   canvas = FALSE,
+                   canvas = useCanvas(x),
                    color = standardColor(x), #mapviewGetOption("vector.palette"),
                    col.regions = standardColRegions(x), #mapviewGetOption("vector.palette"),
                    at = NULL,
@@ -623,7 +644,7 @@ setMethod('mapView', signature(x = 'sfc'),
                    verbose = mapviewGetOption("verbose"),
                    popup = NULL,
                    layer.name = deparse(substitute(x,
-                                                   env = parent.frame(2))),
+                                                   env = parent.frame())),
                    label = makeLabels(x),
                    legend = mapviewGetOption("legend"),
                    legend.opacity = 1,
@@ -633,6 +654,11 @@ setMethod('mapView', signature(x = 'sfc'),
                    maxpoints = getMaxFeatures(x),
                    ...) {
 
+            if (length(x) == 0) {
+              stop("\n", deparse(substitute(x, env = parent.frame())),
+                   " does not contain data \n", call. = FALSE)
+            }
+
             if (mapviewGetOption("platform") == "leaflet") {
 
               leaflet_sfc(sf::st_cast(x),
@@ -759,7 +785,7 @@ setMethod('mapView', signature(x = 'XY'),
           function(x,
                    map = NULL,
                    pane = "auto",
-                   canvas = FALSE,
+                   canvas = useCanvas(x),
                    color = standardColor(x), #mapviewGetOption("vector.palette"),
                    col.regions = standardColRegions(x), #mapviewGetOption("vector.palette"),
                    at = NULL,
@@ -858,74 +884,74 @@ setMethod('mapView', signature(x = 'XYZM'),
 
 
 
-## sfc_POINT ==============================================================
-#' @describeIn mapView \code{\link{st_sfc}}
-
-setMethod('mapView', signature(x = 'sfc_POINT'),
-          function(x, ...) {
-            callNextMethod()
-          }
-)
-
-
-## sfc_MULTIPOINT =========================================================
-#' @describeIn mapView \code{\link{st_sfc}}
-
-setMethod('mapView', signature(x = 'sfc_MULTIPOINT'),
-          function(x, ...) {
-            callNextMethod()
-          }
-)
-
-
-## sfc_LINESTRING =========================================================
-#' @describeIn mapView \code{\link{st_sfc}}
-
-setMethod('mapView', signature(x = 'sfc_LINESTRING'),
-          function(x, ...) {
-            callNextMethod()
-          }
-)
-
-
-## sfc_MULTILINESTRING ====================================================
-#' @describeIn mapView \code{\link{st_sfc}}
-
-setMethod('mapView', signature(x = 'sfc_MULTILINESTRING'),
-          function(x, ...) {
-            callNextMethod()
-          }
-)
-
-
-## sfc_POLYGON =======================================================
-#' @describeIn mapView \code{\link{st_sfc}}
-
-setMethod('mapView', signature(x = 'sfc_POLYGON'),
-          function(x, ...) {
-            callNextMethod()
-          }
-)
-
-
-## sfc_MULTIPOLYGON =======================================================
-#' @describeIn mapView \code{\link{st_sfc}}
-
-setMethod('mapView', signature(x = 'sfc_MULTIPOLYGON'),
-          function(x, ...) {
-            callNextMethod()
-          }
-)
-
-
-## sfc_GEOMETRY =======================================================
-#' @describeIn mapView \code{\link{st_sfc}}
-
-setMethod('mapView', signature(x = 'sfc_GEOMETRY'),
-          function(x, ...) {
-            callNextMethod()
-          }
-)
+# ## sfc_POINT ==============================================================
+# #' @describeIn mapView \code{\link{st_sfc}}
+#
+# setMethod('mapView', signature(x = 'sfc_POINT'),
+#           function(x, ...) {
+#             callNextMethod()
+#           }
+# )
+#
+#
+# ## sfc_MULTIPOINT =========================================================
+# #' @describeIn mapView \code{\link{st_sfc}}
+#
+# setMethod('mapView', signature(x = 'sfc_MULTIPOINT'),
+#           function(x, ...) {
+#             callNextMethod()
+#           }
+# )
+#
+#
+# ## sfc_LINESTRING =========================================================
+# #' @describeIn mapView \code{\link{st_sfc}}
+#
+# setMethod('mapView', signature(x = 'sfc_LINESTRING'),
+#           function(x, ...) {
+#             callNextMethod()
+#           }
+# )
+#
+#
+# ## sfc_MULTILINESTRING ====================================================
+# #' @describeIn mapView \code{\link{st_sfc}}
+#
+# setMethod('mapView', signature(x = 'sfc_MULTILINESTRING'),
+#           function(x, ...) {
+#             callNextMethod()
+#           }
+# )
+#
+#
+# ## sfc_POLYGON =======================================================
+# #' @describeIn mapView \code{\link{st_sfc}}
+#
+# setMethod('mapView', signature(x = 'sfc_POLYGON'),
+#           function(x, ...) {
+#             callNextMethod()
+#           }
+# )
+#
+#
+# ## sfc_MULTIPOLYGON =======================================================
+# #' @describeIn mapView \code{\link{st_sfc}}
+#
+# setMethod('mapView', signature(x = 'sfc_MULTIPOLYGON'),
+#           function(x, ...) {
+#             callNextMethod()
+#           }
+# )
+#
+#
+# ## sfc_GEOMETRY =======================================================
+# #' @describeIn mapView \code{\link{st_sfc}}
+#
+# setMethod('mapView', signature(x = 'sfc_GEOMETRY'),
+#           function(x, ...) {
+#             callNextMethod()
+#           }
+# )
 
 
 ## bbox =======================================================
